COP_FIT <- function(d1,d2,n) {

  #This subroutine perform the goodness of fit for a given number of bivariate copulas (n)
  
  #Input:
  
  #d1 First dataset. Numerical R vector
  #d2 Second dataset. Numerical R vector
  #n  Number of copulas to test for goodness of fit
  
  #Output:
  
  # A list with a summary of the corresponding values of the AIC, BIC and LogLik parameters for goodness of fit.
  # The MLE results for the best copula fit that characterizes the input pair data d1-d2
  
  # Author:
  # 04/2020: G. Torres
  #######################################################################################
  # MLE estimation for data for all copula families
  ######################################################################################
  
  fit<-BiCopEstList(d1, d2, familyset = NA, rotations = FALSE)
  fit_sum<- fit["summary"]
  
  #######################################################################################
  # Selection of best fit under MLE criterion (Could be AIC,BIC,logLik)
  #######################################################################################
  
  ww<-BiCopSelect(d1, d2,  familyset = 1:n, selectioncrit = "AIC", indeptest = FALSE, rotations = FALSE, se = FALSE, presel = TRUE, method = "mle")
  
  #######################################################################################
  # Export of results:
  ####################################################################################### 
  
  x<-as.data.frame(fit_sum)
  
  #Renaming column names with r built in functions
  names(x)[names(x) == "summary.family"] <- "family"
  names(x)[names(x) == "summary.logLik"] <- "LogLik"
  names(x)[names(x) == "summary.AIC"] <- "AIC"
  names(x)[names(x) == "summary.BIC"] <- "BIC"
  
  #Unlist data to export results
  ww1<-unlist(lapply(ww, paste, col.lapse=" "))
  output<-list(x,ww1)
  
  return(output)
}