SIMULATION <- function(cop,p,N) {
  
  #This sub routine generates a synthetic data series of the size Nx1 given a copula (cop) and
  # its corresponding parameters p (size 1x2)
  
  #Input:
  
  #  cop= Copula number ID (according to VineCopula R package)
  #  p  = Copula parameters (p1, p2) a vector of two values. If copula has only one parameter, then p2=0
  #  N  = Number of simulations (length of the resulting vector)
  
  #Output:
  
  # A vector of the synthetic data series of size Nx1
  
  # Author:
  # G. Torres  
  
  #######################################################################################
  # LOADING LIBRARY
  #######################################################################################
  library(VineCopula)
  library(invgamma)
  #######################################################################################
  # SIMULATION OF DATA
  #######################################################################################
  
  #Start synthetic data series by simulating 1 random number.
  data<-runif(1,min=0,max=1) #number samples, min, max
  
  #Creating the copula object corresponding tp the parameters introduced
  obj <- BiCop(family = cop , par =p[1]  , par2 = p[2] )
  
  # Simulation of the remaining values of the synthetic time series
  for (i in 2:N)
  {
    data[i]<-BiCopHinv1(data[i-1],runif(1,min=0,max=1),obj)
  }
  
  #Export of results
  return(data)
 
}